@@ -158,12 +158,9 @@ main (int argc, char *argv[])
     }
 
   ioctl (audio, SNDCTL_DSP_GETBLKSIZE, &abuf_size);
-  if (abuf_size < 1024 || abuf_size > (2*65536))
+  if (abuf_size < 1)
     {
-      if (abuf_size == -1)
-	perror (audio_name);
-      else
-	fprintf (stderr, "Invalid audio buffers size %d\n", abuf_size);
+      perror ("GETBLKSIZE");
       exit (-1);
     }
 
