@@ -114,12 +114,9 @@ main (int argc, char *argv[])
     }
 
   ioctl (audio, SNDCTL_DSP_GETBLKSIZE, &abuf_size);
-  if (abuf_size < 1024 || abuf_size > (2*65536))
+  if (abuf_size < 1))
     {
-      if (abuf_size == -1)
-	perror (AUDIO);
-      else
-	fprintf (stderr, "Invalid audio buffers size %d\n", abuf_size);
+      perror (AUDIO);
       exit (-1);
     }
 
