@@ -10,16 +10,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
-#ifndef __STDC__
-#include <getopt.h>
-#endif /* __STDC__ */
 #include <fcntl.h>
 #include <sys/ioctl.h>
-#ifdef __STDC__
 #include <sys/soundcard.h>
-#else /* __STDC__ */
-#include <linux/soundcard.h>
-#endif /* __STDC__ */
 #include "fmtheaders.h"
 
 /* trying to define independent ioctl for sounddrivers version 1 and 2+ ,
@@ -37,11 +30,7 @@
 #define AUDIO "/dev/dsp"
 
 #define min(a,b) 		((a) <= (b) ? (a) : (b))
-#ifdef __STDC__
 #define d_printf(x)        if (verbose_mode) fprintf x
-#else /* __STDC__ */
-#define d_printf(f,a...)        if (verbose_mode) fprintf (stderr,f,##a)
-#endif /* __STDC__ */
 
 #define VOC_FMT			0
 #define WAVE_FMT		1
@@ -86,7 +75,7 @@ struct fmt_record {
 
 int main (int argc, char *argv[])
 {
-  char c;
+  int c;
 
   command = argv[0];
   if (strstr (argv[0], "vrec")) {
@@ -148,7 +137,7 @@ int main (int argc, char *argv[])
   }
 
   IOCTL(audio, SNDCTL_DSP_GETBLKSIZE, abuf_size);
-  if (abuf_size < 4096 || abuf_size > 65536) {
+  if (abuf_size < 4 || abuf_size > 65536) {
     if (abuf_size == -1)
       perror (AUDIO);
     else
@@ -239,12 +228,8 @@ void write_zeros (unsigned x)
 /* if need a SYNC, 
    (is needed if we plan to change speed, stereo ... during output)
 */
-#ifdef __STDC__
 void 
 sync_dsp(void)
-#else /* __STDC__ */
-inline void sync_dsp(void)
-#endif /* __STDC__ */
 {
   if (ioctl (audio, SNDCTL_DSP_SYNC, NULL) < 0) {
     perror(AUDIO);
@@ -274,12 +259,8 @@ void set_dsp_speed (int dsp_speed)
             because if you have a 16 (or 12) bit card you should have
             stereo (or I'm wrong ?? )
    */
-#ifdef __STDC__
 u_long 
 one_channel(u_char *buf, u_long l, char to_mono, char to_8)
-#else /* __STDC__ */
-inline u_long one_channel(char *buf, u_long l, char to_mono, char to_8)
-#endif /* __STDC__ */
 {
   register u_char *w  = buf;
   register u_char *w2 = buf;
@@ -378,11 +359,7 @@ void vplay (int fd, int ofs, char *name)
       output = 0;
       switch (bp->type) {
         case 0:
-#ifdef __STDC__
           d_printf ((stderr, "Terminator\n"));
-#else /* __STDC__ */
-          d_printf ("Terminator\n");
-#endif /* __STDC__ */
           return;		/* VOC-file stop */
         case 1:
           vd = (Voice_data *)data; COUNT(sizeof(Voice_data));
@@ -392,11 +369,7 @@ void vplay (int fd, int ofs, char *name)
           if (! was_extended) {
             dsp_speed = (int)(vd->tc);
             dsp_speed = 1000000 / (256 - dsp_speed); 
-#ifdef __STDC__
             d_printf ((stderr, "Voice data %d Hz\n", dsp_speed));
-#else /* __STDC__ */
-            d_printf ("Voice data %d Hz\n", dsp_speed);
-#endif /* __STDC__ */
             if (vd->pack) {	/* /dev/dsp can't it */
               fprintf (stderr, "%s: can't play packed .voc files\n", command);
               return;
@@ -427,11 +400,7 @@ void vplay (int fd, int ofs, char *name)
           set_dsp_speed (dsp_speed);
           break;
         case 2:			/* nothing to do, pure data */
-#ifdef __STDC__
           d_printf ((stderr, "Voice continuation\n"));
-#else /* __STDC__ */
-          d_printf ("Voice continuation\n");
-#endif /* __STDC__ */
           break;
         case 3:			/* a silence block, no data, only a count */
           sp = (u_short *)data; COUNT(sizeof(u_short));
@@ -440,38 +409,22 @@ void vplay (int fd, int ofs, char *name)
           sync_dsp();
           set_dsp_speed (dsp_speed);
           silence = ( ((u_long)*sp) * 1000) / dsp_speed; 
-#ifdef __STDC__
           d_printf ((stderr, "Silence for %d ms\n", silence));
-#else /* __STDC__ */
-          d_printf ("Silence for %d ms\n", silence);
-#endif /* __STDC__ */
           write_zeros (*sp);
           break;
         case 4:			/* a marker for syncronisation, no effect */
           sp = (u_short *)data; COUNT(sizeof(u_short));
-#ifdef __STDC__
           d_printf ((stderr, "Marker %d\n", *sp)); 
-#else /* __STDC__ */
-          d_printf ("Marker %d\n", *sp); 
-#endif /* __STDC__ */
           break;
         case 5:			/* ASCII text, we copy to stderr */
           output = 1;
-#ifdef __STDC__
           d_printf ((stderr, "ASCII - text :\n"));
-#else /* __STDC__ */
-          d_printf ("ASCII - text :\n");
-#endif /* __STDC__ */
           break; 
         case 6:			/* repeat marker, says repeatcount */
           /* my specs don't say it: maybe this can be recursive, but
              I don't think somebody use it */
           repeat = *(u_short *)data; COUNT(sizeof(u_short));
-#ifdef __STDC__
           d_printf ((stderr, "Repeat loop %d times\n", repeat));
-#else /* __STDC__ */
-          d_printf ("Repeat loop %d times\n", repeat);
-#endif /* __STDC__ */
           if (filepos >= 0)	/* if < 0, one seek fails, why test another */
             if ( (filepos = lseek (fd, 0, 1)) < 0 ) {
               fprintf(stderr, "%s: can't play loops; %s isn't seekable\n", 
@@ -486,29 +439,17 @@ void vplay (int fd, int ofs, char *name)
         case 7:			/* ok, lets repeat that be rewinding tape */
           if (repeat) {
             if (repeat != 0xFFFF) {
-#ifdef __STDC__
               d_printf ((stderr, "Repeat loop %d\n", repeat));
-#else /* __STDC__ */
-              d_printf ("Repeat loop %d\n", repeat);
-#endif /* __STDC__ */
               --repeat;
             }
             else
-#ifdef __STDC__
               d_printf ((stderr, "Neverending loop\n"));
-#else /* __STDC__ */
-              d_printf ("Neverending loop\n");
-#endif /* __STDC__ */
             lseek (fd, filepos, 0);
             in_buffer = 0;		/* clear the buffer */
             goto Fill_the_buffer;
           }
           else
-#ifdef __STDC__
             d_printf ((stderr, "End repeat loop\n"));
-#else /* __STDC__ */
-            d_printf ("End repeat loop\n");
-#endif /* __STDC__ */
           break;
         case 8:			/* the extension to play Stereo, I have SB 1.0 :-( */
           was_extended = 1;
@@ -522,13 +463,8 @@ void vplay (int fd, int ofs, char *name)
             fprintf (stderr, "%s: can't play packed .voc files\n", command);
             return;
           }
-#ifdef __STDC__
           d_printf ((stderr, "Extended block %s %d Hz\n", 
 				(eb->mode ? "Stereo" : "Mono"), dsp_speed));
-#else /* __STDC */
-          d_printf ("Extended block %s %d Hz\n", 
-				(eb->mode ? "Stereo" : "Mono"), dsp_speed);
-#endif /* __STDC__ */
           break;
         default:
           fprintf (stderr, "%s: unknown blocktype %d. terminate.\n", 
@@ -631,7 +567,7 @@ void start_wave(int fd, u_long cnt)
   wh.format     = PCM_CODE;
   wh.modus      = dsp_stereo ? 2 : 1;
   wh.sample_fq  = dsp_speed;
-  wh.byte_p_spl = (samplesize == 8) ? 1 : 2;
+  wh.byte_p_spl = ((samplesize == 8) ? 1 : 2) * (dsp_stereo ? 2 : 1);
   wh.byte_p_sec = dsp_speed * wh.modus * wh.byte_p_spl;
   wh.bit_p_spl  = samplesize;
   wh.data_chunk = DATA;
