@@ -29,7 +29,9 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <errno.h>
+#ifndef __STDC__
 #include <getopt.h>
+#endif /* __STDC__ */
 #include <sys/soundcard.h>
 
 struct sbi_instrument instr;
@@ -117,7 +119,11 @@ void wait(int delay)
 	sbwrite((char*)&jiffies);
 }
 
+#ifdef __STDC__
+void usage(char *s) 
+#else /* __STDC__ */
 volatile void usage(char *s) 
+#endif /* __STDC__ */
 {
 	fprintf(stderr,
 		"usage: %s [-h] [-o octave] [-t time] [-i instr]\n",s);
