@@ -33,6 +33,7 @@
 #include <xview/frame.h>
 #include <xview/panel.h>
 #include <xview/svrimage.h>
+#include <xview/icon.h>
 #include "locked.bit"
 #include "unlocked.bit"
 #include "rec.bit"
@@ -56,6 +57,19 @@ Panel_item	volume_r[SOUND_MIXER_NRDEVICES];
 Panel_item	buttons[SOUND_MIXER_NRDEVICES];
 int		key;
 
+#ifdef USE_XBM_ICON
+static	Icon		icon;
+static	Pixmap		icon_pm, mask_icon_pm;
+static	Server_image	icon_image, icon_image_mask;
+static	Display *dpy;
+Window	root_win;
+
+#include	"xvmixer.xbm"
+#include	"xvmixer-mask.xbm"
+
+#endif /* USE_XBM_ICON */
+
+
 Server_image locked_image, unlocked_image, rec_image, lock;
 
 int main(argc, argv)
@@ -131,6 +145,41 @@ int main(argc, argv)
 		SERVER_IMAGE_X_BITS,	rec_bits,
 		NULL);
 
+#ifdef USE_XBM_ICON
+
+	dpy = (Display *) xv_get(frame, XV_DISPLAY);
+	root_win = RootWindow (dpy, DefaultScreen(dpy));
+
+	icon_pm = XCreatePixmapFromBitmapData(dpy,
+			root_win, icon_bits, icon_width, icon_height,
+			1, 0, 1);
+
+	mask_icon_pm = XCreatePixmapFromBitmapData(dpy,
+			root_win, mask_icon_bits, mask_icon_width,
+			mask_icon_height, 1, 0, 1);
+
+        icon_image = (Server_image) xv_create(NULL,SERVER_IMAGE,
+			SERVER_IMAGE_PIXMAP, icon_pm, NULL);
+
+	icon_image_mask = (Server_image) xv_create(NULL,SERVER_IMAGE,
+			SERVER_IMAGE_PIXMAP, mask_icon_pm,
+			NULL);
+
+	icon = (Icon) xv_create(frame, ICON,
+			ICON_IMAGE, icon_image,
+			ICON_MASK_IMAGE, icon_image_mask,
+			ICON_TRANSPARENT, TRUE,
+			NULL);
+
+	xv_set(frame,
+		FRAME_ICON, icon,
+		NULL);
+
+
+#endif /* USE_XBM_ICON */
+
+
+
 	key = xv_unique_key();
 	n = 0;
 	for(i=0; i<SOUND_MIXER_NRDEVICES; i++) 
